@@ -90,7 +90,7 @@ class DeepTable:
                 - 'auto'
                     get the columns of categorical type automatically. By default, the object,
                     bool and category will be selected.
-                    if 'auto' the [auto_categorization] will no longer takes effect.
+                    if 'auto' the [auto_categorize] will no longer takes effect.
                 - list of strings
                     e.g. ['x1','x2','x3','..']
 
@@ -99,13 +99,14 @@ class DeepTable:
             pos_label: str or int, (default=None)
                 The label of positive class, used only when task is binary.
 
-            metrics: list of strings, (default=['AUC', 'accuracy'])
+            metrics: list of string or callable object, (default=['accuracy'])
                 List of metrics to be evaluated by the model during training and testing.
                 Typically you will use `metrics=['accuracy']` or `metrics=['AUC']`.
-                Every metric should be a built-in evaluation metric in tf.keras.metrics.
+                Every metric should be a built-in evaluation metric in tf.keras.metrics or a callable object
+                like `r2(y_true, y_pred):...` .
                 See also: https://tensorflow.google.cn/versions/r2.0/api_docs/python/tf/keras/metrics
 
-            auto_categorization: bool, (default=False)
+            auto_categorize: bool, (default=False)
 
             cat_exponent: float, (default=0.5)
 
@@ -282,7 +283,7 @@ class DeepTable:
         self.output_path = self._prepare_output_dir(config.home_dir, self.nets)
         self.preprocessor = DefaultPreprocessor(config)
         self.__current_model = None
-        self.__modelset = modelset.ModelSet(metric=self.config.metrics[0], best_mode=consts.MODEL_SELECT_MODE_AUTO)
+        self.__modelset = modelset.ModelSet(metric=self.config.first_metric_name, best_mode=consts.MODEL_SELECT_MODE_AUTO)
 
     @property
     def task(self):
@@ -304,7 +305,7 @@ class DeepTable:
         monitor = self.config.monitor_metric
         if monitor is None:
             if self.config.metrics is not None and len(self.config.metrics) > 0:
-                monitor = 'val_' + self.config.metrics[0]
+                monitor = 'val_' + self.config.first_metric_name
         return monitor
 
     @property
