@@ -40,7 +40,7 @@ class BatchTrainer:
                  test_as_eval=False,
                  eval_size=0.2,
                  validation_size=0.2,
-                 metrics=[],
+                 eval_metrics=[],
                  dt_config=None,
                  dt_nets=[['dnn_nets']],
                  dt_epochs=5,
@@ -63,8 +63,8 @@ class BatchTrainer:
             raise ValueError('[data_train] must be provided.')
         if dt_config is None:
             raise ValueError('[dt_config] must be provided.')
-        if metrics is None or len(metrics) <= 0:
-            raise ValueError('[metrics] is empty, at least one metric.')
+        if eval_metrics is None or len(eval_metrics) <= 0:
+            raise ValueError('[eval_metrics] is empty, at least one metric.')
 
         if eval_size is not None and (eval_size >= 1.0 or eval_size < 0):
             raise ValueError(f'[eval_size] must be >= 0 and < 1.0.')
@@ -87,7 +87,7 @@ class BatchTrainer:
         self.target = target
         self.eval_size = eval_size
         self.validation_size = validation_size
-        self.metrics = metrics
+        self.eval_metrics = eval_metrics
         self.dt_epochs = dt_epochs
         self.dt_batch_size = dt_batch_size
         self.seed = seed
@@ -100,7 +100,18 @@ class BatchTrainer:
         self.lightgbm_params = lightgbm_params
         self.catboost_params = catboost_params
         self.__prepare_data()
-        self.model_set = modelset.ModelSet(metric=self.metrics[0], best_mode=consts.MODEL_SELECT_MODE_AUTO)
+        self.model_set = modelset.ModelSet(metric=self.first_metric_name, best_mode=consts.MODEL_SELECT_MODE_AUTO)
+
+    @property
+    def first_metric_name(self):
+        if self.eval_metrics is None or len(self.eval_metrics)<=0:
+            raise ValueError('`metrics` is none or empty.')
+        first_metric = self.eval_metrics[0]
+        if isinstance(first_metric, str):
+            return first_metric
+        if callable(first_metric):
+            return first_metric.__name__
+        raise ValueError('`metric` must be string or callable object.')
 
     def __prepare_data(self):
         if self.train is None:
@@ -110,13 +121,19 @@ class BatchTrainer:
 
         if self.train.columns.dtype != 'object':
             self.train.columns = ['x_' + str(c) for c in self.train.columns]
-        if self.eval_size > 0:
-            self.X_train, self.X_eval = train_test_split(self.train, test_size=self.eval_size, random_state=self.seed)
-            self.y_eval = self.X_eval.pop(self.target)
-        else:
+
+        if self.test_as_eval and self.test is not None:
             self.X_train = self.train
-            self.X_eval = None
-            self.y_eval = None
+            self.X_eval = self.test
+            self.test = None
+        else:
+            if self.eval_size > 0:
+                self.X_train, self.X_eval = train_test_split(self.train, test_size=self.eval_size,
+                                                             random_state=self.seed)
+            else:
+                self.X_train = self.train
+                self.X_eval = None
+                self.y_eval = None
 
         if self.test is not None:
             if not isinstance(self.test, pd.DataFrame):
@@ -135,8 +152,9 @@ class BatchTrainer:
         else:
             self.X_test = None
             self.y_test = None
-        self.y_train = self.X_train.pop(self.target)
 
+        self.y_train = self.X_train.pop(self.target).values
+        self.y_eval = self.X_eval.pop(self.target).values if self.X_eval is not None else None
         self.task, labels = deeptable.infer_task_type(self.y_train)
         self.classes = len(labels)
         gc.collect()
@@ -148,7 +166,7 @@ class BatchTrainer:
         return self.train_model(self.model_set, config, lgbm_fit, 'LightGBM', **self.lightgbm_params)
 
     def start(self, models=['dt']):
-        self.model_set = modelset.ModelSet(metric=self.metrics[0], best_mode=consts.MODEL_SELECT_MODE_AUTO)
+        self.model_set = modelset.ModelSet(metric=self.first_metric_name, best_mode=consts.MODEL_SELECT_MODE_AUTO)
         for config in self.dt_config:
             if models is None or 'lightgbm' in models:
                 with timer('LightGBM'):
@@ -183,10 +201,11 @@ class BatchTrainer:
         fixed_embedding_dim = conf.fixed_embedding_dim
         if 'fm_nets' in nets:
             fixed_embedding_dim = True
-        print(f'metrics:{self.metrics}')
-        conf = conf._replace(nets=nets, metrics=[self.metrics[0]],
-                             fixed_embedding_dim=fixed_embedding_dim,
-                             )
+        print(f'train metrics:{config.metrics}')
+        print(f'eval metrics:{self.eval_metrics}')
+        # conf = conf._replace(nets=nets, metrics=[self.eval_metrics[0]],
+        #                      fixed_embedding_dim=fixed_embedding_dim,
+        #                      )
 
         dt = deeptable.DeepTable(config=conf)
 
@@ -205,7 +224,7 @@ class BatchTrainer:
                                                                         n_jobs=self.n_jobs)
             print(f'Scoring...')
             oof_preds = dt.proba2predict(oof_proba)
-            oof_score = calc_score(self.y_train, oof_proba, oof_preds, self.metrics, self.task,
+            oof_score = calc_score(self.y_train, oof_proba, oof_preds, self.eval_metrics, self.task,
                                    dt.pos_label)
             model_set.push(
                 modelset.ModelInfo('oof', f'{config.name} - {nets} - CV - oof', dt, oof_score,
@@ -214,7 +233,7 @@ class BatchTrainer:
 
             if eval_proba is not None:
                 eval_preds = dt.proba2predict(eval_proba)
-                eval_cv_score = calc_score(self.y_eval, eval_proba, eval_preds, self.metrics, self.task,
+                eval_cv_score = calc_score(self.y_eval, eval_proba, eval_preds, self.eval_metrics, self.task,
                                            dt.pos_label)
                 model_set.push(
                     modelset.ModelInfo('cv-eval', f'{config.name} - {nets} - CV - eval', dt, eval_cv_score,
@@ -225,7 +244,7 @@ class BatchTrainer:
                 all_model_proba = dt.predict_proba_all(self.X_eval)
                 for fold_name, fold_proba in all_model_proba.items():
                     fold_preds = dt.proba2predict(fold_proba)
-                    fold_score = calc_score(self.y_eval, fold_proba, fold_preds, self.metrics, self.task,
+                    fold_score = calc_score(self.y_eval, fold_proba, fold_preds, self.eval_metrics, self.task,
                                             dt.pos_label)
                     print(f'\n------------{fold_name} -------------Eval score:\n{fold_score}')
                     model_set.push(
@@ -244,7 +263,7 @@ class BatchTrainer:
             if self.X_eval is not None:
                 proba = dt.predict_proba(self.X_eval, model_selector=consts.MODEL_SELECTOR_BEST)
                 preds = dt.proba2predict(proba)
-                score = calc_score(self.y_eval, proba, preds, self.metrics, self.task, dt.pos_label)
+                score = calc_score(self.y_eval, proba, preds, self.eval_metrics, self.task, dt.pos_label)
                 # score = dt.evaluate(self.X_test, self.y_test)
                 print(f'\n------------{nets} -------------Eval score:\n{score}')
                 model_set.push(
@@ -259,7 +278,7 @@ class BatchTrainer:
 
             if self.X_test is not None:
                 test_proba = dt.predict_proba(self.X_test)
-                score = str(round(history.history[self.metrics[0]][-1], 5))
+                score = str(round(history.history[self.first_metric_name][-1], 5))
                 file = f'{dt.output_path}{score}_{"_".join(nets)}.csv'
                 pd.DataFrame(test_proba).to_csv(file, index=False)
 
@@ -275,7 +294,7 @@ class BatchTrainer:
             params['iterations'] = 20
 
         conf = config
-        conf = conf._replace(apply_gbm_features=False, auto_categorization=False)
+        conf = conf._replace(apply_gbm_features=False, auto_categorize=False)
         dt = deeptable.DeepTable(config=conf)
         print('Preparing datasets...')
 
@@ -289,30 +308,36 @@ class BatchTrainer:
         X_val[cat_vars] = X_val[cat_vars].astype('int')
         X_val[cont_vars] = X_val[cont_vars].astype('float')
 
-        X_eval = dt.preprocessor.transform_X(self.X_eval)
-        X_eval[cat_vars] = X_eval[cat_vars].astype('int')
-        X_eval[cont_vars] = X_eval[cont_vars].astype('float')
-
         pos_label = dt.preprocessor.pos_label
-        y_eval = self.y_eval
+
         model = fit_fn(X, y,
                        X_val, y_val,
                        cat_vars,
                        self.task,
                        params)
-        preds = model.predict(X_eval)
 
-        if self.task == consts.TASK_REGRESSION:
-            proba = preds
-        elif self.task == consts.TASK_MULTICLASS:
-            proba = model.predict_proba(X_eval)
+        if self.X_eval is not None:
+            X_eval = dt.preprocessor.transform_X(self.X_eval)
+            X_eval[cat_vars] = X_eval[cat_vars].astype('int')
+            X_eval[cont_vars] = X_eval[cont_vars].astype('float')
+
+            y_eval = self.y_eval
+
+            preds = model.predict(X_eval)
+
+            if self.task == consts.TASK_REGRESSION:
+                proba = preds
+            elif self.task == consts.TASK_MULTICLASS:
+                proba = model.predict_proba(X_eval)
+            else:
+                proba = model.predict_proba(X_eval)[:, 1]
+
+            print('Scoring...')
+            score = calc_score(self.y_eval, proba, preds, self.eval_metrics, self.task, pos_label)
+            model_set.push(modelset.ModelInfo('eval', model_name, model, score, dt=dt))
+            print(f'\n------------{model_name} -------------Eval score:\n{score}')
         else:
-            proba = model.predict_proba(X_eval)[:, 1]
-
-        print('Scoring...')
-        score = calc_score(self.y_eval, proba, preds, self.metrics, self.task, pos_label)
-        model_set.push(modelset.ModelInfo('eval', model_name, model, score, dt=dt))
-        print(f'\n------------{model_name} -------------Eval score:\n{score}')
+            print('No evaluation dataset specified.')
         print(f'{model_name} finished.')
 
         return model, score
@@ -478,7 +503,7 @@ class BatchTrainer:
         score = None
         if y is not None and score_dt is not None:
             preds = score_dt.proba2predict(proba_avg)
-            score = calc_score(y, proba_avg, preds, self.metrics, score_dt.task, score_dt.pos_label)
+            score = calc_score(y, proba_avg, preds, self.eval_metrics, score_dt.task, score_dt.pos_label)
             print(f'\nEnsemble Test Score:\n{score}')
         if submission is not None and submission.shape[0] == proba_avg.shape[0]:
             submission[submission_target] = proba_avg[:, 0]
