@@ -9,6 +9,7 @@ from deeptables.datasets import dsutils
 from deeptables.models import deeptable
 from sklearn.datasets import load_boston
 import pandas as pd
+from tests.misc import r2_c
 
 
 class Test_Batch_Trainer:
@@ -21,7 +22,7 @@ class Test_Batch_Trainer:
             embeddings_output_dim=0,
             apply_gbm_features=False,
             auto_discrete=True,
-            auto_categorization=False,
+            auto_categorize=False,
             cat_exponent=0.4,
             cat_remain_numeric=True,
             # optimizer=keras.optimizers.RMSprop(),
@@ -30,7 +31,7 @@ class Test_Batch_Trainer:
         bt = batch_trainer.BatchTrainer(data, 'target',
                                         eval_size=0.2,
                                         validation_size=0.2,
-                                        metrics=['AUC', 'accuracy', 'recall', 'precision', 'f1'],
+                                        eval_metrics=['AUC', 'accuracy', 'recall', 'precision', 'f1'],
                                         # AUC/recall/precision/f1/mse/mae/msle/rmse/r2
                                         dt_config=conf,
                                         verbose=0,
@@ -55,7 +56,7 @@ class Test_Batch_Trainer:
         bt = batch_trainer.BatchTrainer(data, 'x_14',
                                         eval_size=0.2,
                                         validation_size=0.2,
-                                        metrics=['AUC', 'accuracy', 'recall', 'precision', 'f1'],
+                                        eval_metrics=['AUC', 'accuracy', 'recall', 'precision', 'f1'],
                                         # AUC/recall/precision/f1/mse/mae/msle/rmse/r2
                                         dt_config=conf,
                                         verbose=0,
@@ -81,7 +82,7 @@ class Test_Batch_Trainer:
         bt = batch_trainer.BatchTrainer(data, 'x_14',
                                         eval_size=0.2,
                                         validation_size=0.2,
-                                        metrics=['AUC', 'accuracy', 'recall', 'precision', 'f1'],
+                                        eval_metrics=['AUC', 'accuracy', 'recall', 'precision', 'f1'],
                                         # AUC/recall/precision/f1/mse/mae/msle/rmse/r2
                                         dt_config=conf,
                                         verbose=0,
@@ -106,7 +107,7 @@ class Test_Batch_Trainer:
         bt = batch_trainer.BatchTrainer(data, 'x_14',
                                         eval_size=0.2,
                                         validation_size=0.2,
-                                        metrics=['AUC', 'accuracy', 'recall', 'precision', 'f1'],
+                                        eval_metrics=['AUC', 'accuracy', 'recall', 'precision', 'f1'],
                                         # AUC/recall/precision/f1/mse/mae/msle/rmse/r2
                                         dt_config=conf,
                                         verbose=0,
@@ -127,9 +128,9 @@ class Test_Batch_Trainer:
                         'dnn_activation': 'relu'},
             fixed_embedding_dim=False,
             embeddings_output_dim=0,
-            apply_gbm_features=True,
+            apply_gbm_features=False,
             auto_discrete=False,
-            auto_categorization=False,
+            auto_categorize=False,
             cat_exponent=0.2,
             cat_remain_numeric=True,
         )
@@ -138,7 +139,7 @@ class Test_Batch_Trainer:
                                         eval_size=0.2,
                                         validation_size=0.2,
                                         # metrics=['AUC','accuracy','recall','precision','f1'], #auc/recall/precision/f1/mse/mae/msle/rmse/r2
-                                        metrics=['mse', 'rmse', 'r2', 'mae'],
+                                        eval_metrics=[r2_c, 'RootMeanSquaredError', 'mse', 'rmse', 'r2', 'mae'],
                                         # auc/recall/precision/f1/mse/mae/msle/rmse/r2
                                         verbose=0,
                                         dt_config=conf,
@@ -148,7 +149,7 @@ class Test_Batch_Trainer:
                                         )
 
         ms = bt.start()
-        assert ms.leaderboard().shape[1], 6
+        assert ms.leaderboard().shape, (3, 8)
 
     def test_run_multiclass(self):
         data = dsutils.load_glass_uci()
@@ -163,7 +164,7 @@ class Test_Batch_Trainer:
         bt = batch_trainer.BatchTrainer(data, 'x_10',
                                         eval_size=0.2,
                                         validation_size=0.2,
-                                        metrics=['AUC', 'accuracy', 'recall', 'precision', 'f1'],
+                                        eval_metrics=['AUC', 'accuracy', 'recall', 'precision', 'f1'],
                                         # AUC/recall/precision/f1/mse/mae/msle/rmse/r2
                                         dt_config=conf,
                                         verbose=0,
@@ -190,7 +191,7 @@ class Test_Batch_Trainer:
                                         data_test=data,
                                         eval_size=0.2,
                                         validation_size=0.2,
-                                        metrics=['AUC', 'accuracy', 'recall', 'precision', 'f1'],
+                                        eval_metrics=['AUC', 'accuracy', 'recall', 'precision', 'f1'],
                                         # AUC/recall/precision/f1/mse/mae/msle/rmse/r2
                                         dt_config=conf,
                                         verbose=0,
@@ -213,7 +214,7 @@ class Test_Batch_Trainer:
         bt = batch_trainer.BatchTrainer(data, 'x_14',
                                         eval_size=0.2,
                                         validation_size=0.2,
-                                        metrics=['AUC', 'accuracy', 'recall', 'precision', 'f1'],
+                                        eval_metrics=['AUC', 'accuracy', 'recall', 'precision', 'f1'],
                                         # AUC/recall/precision/f1/mse/mae/msle/rmse/r2
                                         dt_config=conf,
                                         verbose=0,
@@ -250,7 +251,7 @@ class Test_Batch_Trainer:
         bt = batch_trainer.BatchTrainer(data, 'x_14',
                                         eval_size=0.2,
                                         validation_size=0.2,
-                                        metrics=['AUC', 'accuracy', 'recall', 'precision', 'f1'],
+                                        eval_metrics=['AUC', 'accuracy', 'recall', 'precision', 'f1'],
                                         # AUC/recall/precision/f1/mse/mae/msle/rmse/r2
                                         dt_config=conf,
                                         verbose=0,
@@ -287,7 +288,7 @@ class Test_Batch_Trainer:
         bt = batch_trainer.BatchTrainer(data, 'x_14',
                                         eval_size=0.2,
                                         validation_size=0.2,
-                                        metrics=['AUC', 'accuracy', 'recall', 'precision', 'f1'],
+                                        eval_metrics=['AUC', 'accuracy', 'recall', 'precision', 'f1'],
                                         # AUC/recall/precision/f1/mse/mae/msle/rmse/r2
                                         dt_config=conf,
                                         verbose=0,
@@ -314,7 +315,7 @@ class Test_Batch_Trainer:
         bt = batch_trainer.BatchTrainer(data, 'x_14',
                                         eval_size=0.2,
                                         validation_size=0.2,
-                                        metrics=['AUC', 'accuracy', 'recall', 'precision', 'f1'],
+                                        eval_metrics=['AUC', 'accuracy', 'recall', 'precision', 'f1'],
                                         dt_config=conf,
                                         verbose=0,
                                         dt_epochs=1,
@@ -338,7 +339,7 @@ class Test_Batch_Trainer:
         bt = batch_trainer.BatchTrainer(data, 'x_14',
                                         eval_size=0,
                                         validation_size=0.2,
-                                        metrics=['AUC', 'accuracy', 'recall', 'precision', 'f1'],
+                                        eval_metrics=['AUC', 'accuracy', 'recall', 'precision', 'f1'],
                                         dt_config=conf,
                                         verbose=0,
                                         dt_epochs=1,
@@ -363,7 +364,7 @@ class Test_Batch_Trainer:
         bt = batch_trainer.BatchTrainer(data, 'x_14',
                                         eval_size=0,
                                         validation_size=0.2,
-                                        metrics=['AUC', 'accuracy', 'recall', 'precision', 'f1'],
+                                        eval_metrics=['AUC', 'accuracy', 'recall', 'precision', 'f1'],
                                         dt_config=conf,
                                         verbose=0,
                                         dt_epochs=1,
@@ -396,8 +397,8 @@ class Test_Batch_Trainer:
         bt = batch_trainer.BatchTrainer(data, 'x_14',
                                         eval_size=0,
                                         validation_size=0.2,
-                                        metrics=['AUC', 'accuracy', 'recall', 'precision', 'f1'],
-                                        dt_config=[conf1,conf2],
+                                        eval_metrics=['AUC', 'accuracy', 'recall', 'precision', 'f1'],
+                                        dt_config=[conf1, conf2],
                                         verbose=0,
                                         dt_epochs=1,
                                         cross_validation=True,
@@ -408,7 +409,6 @@ class Test_Batch_Trainer:
         ms = bt.start(models=['dt'])
         assert len(ms.get_models()), 2
 
-
     def test_leaderboard(self):
         data = dsutils.load_adult().head(1000)
         conf = deeptable.ModelConfig(
@@ -422,7 +422,7 @@ class Test_Batch_Trainer:
         bt = batch_trainer.BatchTrainer(data, 'x_14',
                                         eval_size=0.2,
                                         validation_size=0.2,
-                                        metrics=['AUC', 'accuracy', 'recall', 'precision', 'f1'],
+                                        eval_metrics=['AUC', 'accuracy', 'recall', 'precision', 'f1'],
                                         dt_config=conf,
                                         verbose=0,
                                         dt_epochs=1,
